--[[

This file is part of RampageAI.

RampageAI is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

RampageAI is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with RampageAI; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]


--[[ All monster-specific and monster-type specific entries take the form of:

{ ID, prio, atk, skLvl, skDly, skMax, aSkLv, aSkDl, aSkMx, defOnly, kite,
		ffa, hlBm, mammo, aTer, aBmb },

	- "ID" is the monster's type/id, depending on which table the monster-settings
		are found.

		Monster types can be found from RO Empire's monster database
			(listed as MID, in parenthesis after the monster's name).
			Other databases may show this value as well.

		Specific monster IDs may vary, and are more difficult to find out.
		As I cannot think of an easy way to determine specific IDs, please
		ask your local Ragnarok Online guru to help you :D

	- "prio" is a value to prioritize killing of monsters.

		Clarification: If a "Steel Chonchon" has a priority of 5 and
			a "Zenorc" has a priority of 3, the homunculus will
			attack the steel chonchon before the zenorc.

	- "atk" is a boolean (aka true/false) that determines whether or
		not the homunculus should attack the monster with physical attacks

	- "skLvl" is the highest level of an attack skill that is allowed to be
		used against the monster (0 to disable homunculus skills against it)

		NOTE: Disabling "AllowSkills" in Config.lua will disable *ALL*
			homunculus skill usage, regardless of monster-specific settings.

	- "skDly" is the minimum amount of time (in milliseconds) that should be
		waited in between uses of a homunculus skill against this monster.

	- "skMax" is the maximum number of times to cast a homunculi's skills against
		the monster (-1 for infinite)

	- "aSkLv" is the highest level of an auto-attack skill to be cast against the monster
		(0 to disable alchemist skills against the monster)

	- "aSkDl" is the minimum amount of time (in milliseconds) that should be
		waited in between uses of a auto-attack skill against this monster

	- "aSkMx" is the maximum number of times to cast auto-attack skill against
		the monster (-1 for infinite)

	- "defOnly" is a boolean (true/false) to decide whether or not the monster
		should be attacked ONLY if it attacks you first

	- "kite" is a boolean (true/false) that will decide if the monster should be
		kite-tanked or attacked with the intention of killing.

			NOTE: Kiting is experimental and should be used with care.

			NOTE: When defending against monsters that are supposed to
				be kited, they will be the last to get targetted.
				(regular killing is usually faster and faster
				defense is important)

	- "ffa" is a boolean (true/false) to determine whether or not a monster is
		considered "free-for-all", and can be "kill-stealed" at any time.
		This is intended for use with MVPs.

	- "hlBm" is a boolean (true/false) to determine if a monster would be damaged
		by casting "heal" on it, sometimes called "heal bombing".

	- "mammo" is the maximum number of times to cast Mammonite against the monster
		(0=disabled, -1=unlimited)

	- "aTer" is the maximum number of times to waste an acid bottle on the monster
		(0=disabled, -1=unlimited)

	- "aBmb" is the maximum number of times to waste bottle grenade and acid bottle
		against the monster (0=disabled,-1=unlimited)


	NOTE: Setting any option to "nil" will use the default.	This is also true for
		leaving the option off completely (if its after all the options you
		set for the monster)

	NOTE: This table is optimized when the script is initialized.


	Alternatively, you may specify each of the above options (except ID) by their
	names. This provides the ability to have a more readable Monsters.lua, as well
	as allowing the order of options to be changed.

	EXAMPLE
		{ 1078, skLvl=0, aSkLv=0, prio=0, atk=true, },

--]]

---------------------------
-- Monster-Type Settings --
---------------------------

-- This line indicates the table of monsters will be held in a variable named...
MonsterTypeDB = {

--[[

For easier reference:
{ ID, prio, atk, skLvl, skDly, skMax, aSkLv, aSkDl, aSkMx, defOnly, kite,
		ffa, hlBm, mammo, aTer, aBmb },

--]]

--=== Example ===--
--[[ This example will prioritize killing of plants below every other monster, but
	will not allow the homunculus to use skills against the plants. It will also
	not allow sword bolts to be casted against plants
--]]
{ 1078, prio=0, atk=true, skLvl=0, aSkLv=0 },					-- Red Plant
{ 1079, prio=0, atk=true, skLvl=0, aSkLv=0 },					-- Blue Plant
{ 1080, prio=0, atk=true, skLvl=0, aSkLv=0 },					-- Green Plant
{ 1081, prio=0, atk=true, skLvl=0, aSkLv=0 },					-- Yellow Plant
{ 1082, prio=0, atk=true, skLvl=0, aSkLv=0 },					-- White Plant
{ 1083, prio=0, atk=true, skLvl=0, aSkLv=0 },					-- Shining Plant
{ 1084, prio=0, atk=true, skLvl=0, aSkLv=0 },					-- Red Mushroom
{ 1085, prio=0, atk=true, skLvl=0, aSkLv=0 },					-- Black Mushroom

-- These next ones will prevent the homunculus from attacking summoned plants
--	(NOTE: These use the old way of setting monster-type options)
{ 1555, nil, false, 0, nil, nil, 0 },						-- Summoned Parasite
{ 1575, nil, false, 0, nil, nil, 0 },						-- Summoned Flora
{ 1579, nil, false, 0, nil, nil, 0 },						-- Summoned Hydra
{ 1589, nil, false, 0, nil, nil, 0 },						-- Summoned Mandragora
{ 1590, nil, false, 0, nil, nil, 0 },						-- Summoned Geographer

-- A few heal-bombable monsters, as examples
{ 1015, hlBm=true },								-- Zombie
{ 1076, hlBm=true },								-- Skeleton
{ 1152, hlBm=true },								-- Orc Skeleton
{ 1153, hlBm=true },								-- Orc Zombie


--[[

For easier reference:
{ ID, prio, atk, skLvl, skDly, skMax, aSkLv, aSkDl, aSkMx, defOnly, kite,
		ffa, hlBm, mammo, aTer, aBmb },

--]]

-- Put your own monster types here




-- End of the monster type table
}

----------------------------
-- Specific Monster Table --
----------------------------

MonsterSpecDB = {

-- NOTE: Unfortunately Monster IDs are server (and sometimes zone) specific, so there are no examples.

--[[

For easier reference:
{ ID, prio, atk, skLvl, skDly, skMax, aSkLv, aSkDl, aSkMx, defOnly, kite,
		ffa, hlBm, mammo, aTer, aBmb },

--]]

-- Put your own specific monsters here

-- End of specific monster table
}

------------------------
-- Supporting Options --
------------------------

--[[ This is the default monster entry

	We want default priority to be 1, allow melee attacks, allow
	skills to be used up to level 5, wait 0.5 seconds between casting
	of attack skills, cast only one homunculus skill total,
	cast up to level 5 alch skills, wait 1 second between casting of
	alch skills, cast alch skills as many times as needed, and never
	"heal bomb" the monster.

	NOTE: ID has no effect on this, but is left in so as to conform to
		the above descriptions.
--]]
DefaultMonsterSettings = { nil, prio=1, atk=true, skLvl=5, skDly=500, skMax=1, aSkLv=5,
				aSkDl=1000, aSkMx=-1, defOnly=false, kite=false, ffa=false,
				hlBm=false, mammo=0, aTer=0, aBmb=0 }
